#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 1999-2021 Alibaba Group Holding Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ..core.base import MarsError


class ActorPoolNotStarted(MarsError):
    pass


class ActorNotExist(Exception):
    pass


class ActorAlreadyExist(Exception):
    pass


class NoIdleSlot(Exception):
    pass


class ServerClosed(Exception):
    pass


class CannotCancelTask(Exception):
    pass


class Return(Exception):
    def __init__(self, value):
        self.value = value
